@@ -87,7 +87,7 @@ class CameraSystem(LoggerMixIn, metaclass=abc.ABCMeta):
         if verbose:
             self.logger.sh.setLevel(int(verbose))
         else:
-            self.logger.sh.setLevel(logging.CRITICAL)
+            self.logger.sh.setLevel(logging.WARNING)
 
         if log_file:
             self.logger.start_file_logger(log_file)
@@ -711,7 +711,7 @@ class BaseCamera(LoggerMixIn, metaclass=abc.ABCMeta):
 
         if write:
             self._notify(CameraEvent.EXPOSURE_WRITING)
-            await self.loop.run_in_executor(None, exposure.write)
+            await exposure.write()
             self._notify(CameraEvent.EXPOSURE_WRITTEN)
 
         return exposure
